fn yaml_safe_string(s: &str) -> StringExpand description
Quote a string value if it could be misinterpreted by YAML.
YAML special values include: null, true, false, ~, -, numbers, and strings starting with special characters like !, &, *, >, |, {, [, :, #, @, `.