FenceKind

Enum FenceKind 

pub enum FenceKind {
Show 17 variants Adapter, Memory, Policy, Injection, Provider, Cache, Trajectory, Agent, Intent, Tool, Rag, Json, Xml, Constraints, Tools, Manifest, Flow,
}
Supported fence block types (single source of truth)

Variants



Adapter



Memory



Policy



Injection



Provider



Cache



Trajectory



Agent



Intent



Tool



Rag



Json



Xml



Constraints



Tools



Manifest



Flow